# Gaia boat's control module
## What does it do

This module is responsible for the integration and communication of the internal software modules.

## Usage and installation

### Installation

Installation for this module is made via the Python Package Index (PIP/PyPi), you can install the package through the following command: `pip install gaia-control` or by adding it on your `requirements.txt` file.

### Usage

